WireGuardKeyPair class
A WireGuard keypair: 32-byte X25519 private/public keys, base64 encoded.
Constructors
- WireGuardKeyPair({required String privateKey, required String publicKey})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → String
-
32-byte private key, base64 encoded (matches
wg genkey).final - publicKey → String
-
32-byte public key, base64 encoded (matches
wg pubkey).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited